<div class="user-dashboard">
    <div class="container">
        <div class="row">
            <div class="col-6"> 
                <h3>Country Names</h3>
            </div>
            <div class="col-6" style="text-align: right;"> 
                <button class="btn-save" onclick="addform()">New</button>
            </div>
            <div class="col-xl-12 col-lg-12">
                <table id="listTable" class="table" style="width:100%">
                    <thead>
                        <tr>
                            <th style="width:150px">Code</th>
                            <th>Country Name</th>
                            <th style="width:50px">Status</th>
                            <th style="width:100px"></th>
                        </tr>
                    </thead>                                     
                    <tbody id="tbl_content">
                        <tr>
                            <td colspan='4'> 
                                <?php echo loadingText("Loading Country Names");?>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<!--<button onclick="openModal()">Open Modal</button>
<div id="myModal" class="modal fade"  tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-bs-backdrop="static">>
  <div class="modal-dialog modal-dialog-centered">
  <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
             <div class="modal-body">
    
            <div class="tab-container">
                <div class="tabs">
                    <button class="tab-btn active" onclick="toggleTab(1)">Tab 1</button>
                    <button class="tab-btn" onclick="toggleTab(2)">Tab 2</button>
                </div>
                <div class="tab-content" id="tab1">
                    <p>This is the content of Tab 1.</p>
                </div>
                <div class="tab-content" id="tab2">
                    <p>This is the content of Tab 2.</p>
                </div>
            </div>
            </div>
            <div class="modal-footer">
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn btn-primary">Continue</button>
            </div>
  </div>
</div>
</div>  -->



<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Country Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
            <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                <div class="row">
                    <span id="ErrCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CountryName" id="CountryName" placeholder="Country Name" onkeypress="clearInput('CountryName')">
                        <span id="ErrCountryName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">International Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="InternationalCode" name="InternationalCode" placeholder="International Code" value="" onkeypress="clearInput('InternationalCode')">
                        <span id="ErrInternationalCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">Telecom Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="TelecomCode" name="TelecomCode" placeholder="Telecom Code" value="" onkeypress="clearInput('TelecomCode')">
                        <span id="ErrTelecomCode" class="error_msg" style="color: red;"></span>
                    </div>
                   
                  
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>  
            </form>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Country Name</h5>
               <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
            <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
            <input type="hidden" name="ID" id="editID">
                <div class="row">
                    <span id="ErreditCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label>
                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="CountryName" id="editCountryName" placeholder="Country Name" value="" onkeypress="clearInput('editCountryName')">
                        <span id="ErreditCountryName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">International Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editInternationalCode" name="InternationalCode" placeholder="International Code" value="" onkeypress="clearInput('editInternationalCode')">
                        <span id="ErreditInternationalCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">Telecom Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editTelecomCode" name="TelecomCode" placeholder="Telecom Code" value="" onkeypress="clearInput('editTelecomCode')">
                        <span id="ErreditTelecomCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1">Active</option>
                            <option value="0">Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
             </form>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Country Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Country Code</div>
                         <div id="viewCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Country Name</div>
                         <div id="viewCountryName"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">International Code</div>
                         <div id="viewInternationalCode"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Telecom Code</div>
                         <div id="viewTelecomCode"></div>
                    </div>
                    
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                         <div id="viewRemarks"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                         <div id="viewStatus"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                         <div id="viewCreatedOn"></div>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
/* 
// Get the modal
  var modal = document.getElementById('myModal');

  // Function to open the modal
  function openModal() {
    modal.style.display = 'flex';
  }

  // Function to close the modal
  function closeModal() {
    modal.style.display = 'none';
  }

  // Close the modal if the user clicks outside of it
  window.onclick = function(event) {
    if (event.target === modal) {
      closeModal();
    }
  };



 // Script for default tab
        document.getElementById('tab1').style.display = 'block';
        document.querySelector('.tab-btn:nth-child(1)').classList.add('active');

        // Existing toggleTab function
        function toggleTab(tabIndex) {
            // Hide all tab contents
            document.querySelectorAll('.tab-content').forEach(tabContent => {
                tabContent.style.display = 'none';
            });

            // Remove active class from all tabs
            document.querySelectorAll('.tab-btn').forEach(tabBtn => {
                tabBtn.classList.remove('active');
            });

            // Show the selected tab content
            document.getElementById('tab' + tabIndex).style.display = 'block';

            // Add active class to the clicked tab
            document.querySelector('.tab-btn:nth-child(' + tabIndex + ')').classList.add('active');
        }  */
        
function list() {
      $('#Success').modal("hide");
    $.post(URL+ "webservice.php?action=l&method=mccol","",function(data){
      var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            i=0;
            $.each(obj.data, function (index, data) {
                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                            + '<td>' + data.Code + '</td>'
                            + '<td>' + data.CountryName + '</td>' 
                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
                             + '<td style="text-align:right">' 
                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mccol\',\''+data.CountryName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                               + '</td>'
                             + '</tr>' 
                      + '</tr>';
                      i++;
            });
            if(obj.data.length==0){
            html += '<tr>'
                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
                + '</tr>'
            }   
            $('#tbl_content').html(html);
        } else {
             $('#popupcontent').html( error(obj.message));
        }  
    });
}

setTimeout("list()",2000);

function addform(){
    $('#confirmationtoadd').modal("show"); 
    $('#Code').val(""); 
    $('#InternationalCode').val(""); 
    $('#TelecomCode').val(""); 
    $('#CountryName').val(""); 
    $('#Remarks').val("");
    
    $('#ErrCode').html(""); 
    $('#ErrInternationalCode').html(""); 
    $('#ErrTelecomCode').html(""); 
    $('#ErrCountryName').html(""); 
    $('#ErrRemarks').html("");
      
    $("#Code").removeClass("highlight_error"); 
    $("#InternationalCode").removeClass("highlight_error"); 
    $("#TelecomCode").removeClass("highlight_error"); 
    $("#CountryName").removeClass("highlight_error"); 
    $("#Remarks").removeClass("highlight_error"); 
     
}

function add(){
        var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
         $("#Code").addClass("highlight_error");
            error++;
    }  else {
        $("#Code").removeClass("highlight_error");
            $('#ErrCode').html(""); 
    } 
    if ($('#InternationalCode').val()==""){
            $('#ErrInternationalCode').html("Please enter International Code");
          $("#InternationalCode").addClass("highlight_error"); 
           error++;
    }  else {
         $("#InternationalCode").removeClass("highlight_error"); 
            $('#ErrInternationalCode').html(""); 
    } 
    if ($('#TelecomCode').val()==""){
            $('#ErrTelecomCode').html("Please enter Telecom Code");
          $("#TelecomCode").addClass("highlight_error"); 
            error++;
    }  else {
          $("#TelecomCode").removeClass("highlight_error"); 
            $('#ErrTelecomCode').html(""); 
    }
  
    if ($('#CountryName').val()==""){
            $('#ErrCountryName').html("Please enter Country Name");
          $("#CountryName").addClass("highlight_error"); 
           error++;
    }  else {
         $("#CountryName").removeClass("highlight_error"); 
            $('#ErrCountryName').html(""); 
    }  
     if(error==0){
        var param = $('#frm_create').serialize();
        $.post(URL+"webservice.php?action=a&method=mccol",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoadd').modal("hide"); 
             $('#Success').modal("show");    
        }   else {
            $('#ErrCommon').html(print_inlineError(obj.message));
        }
    });
   } 
   
}

function editform(ID){
     $('#confirmationtoedit').modal("show"); 
     $('#ErreditCode').html(""); 
     $('#ErreditInternationalCode').html(""); 
     $('#ErreditTelecomCode').html(""); 
     $('#ErreditCountryName').html(""); 
     $('#ErreditRemarks').html("");
     $("#editCode").removeClass("highlight_error"); 
     $("#editInternationalCode").removeClass("highlight_error"); 
     $("#editTelecomCode").removeClass("highlight_error"); 
     $("#editCountryName").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error");
      $.post(URL+ "webservice.php?action=g&method=mccol&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            $.each(obj.data, function (index, data) {
                $('#editCode').val(data.Code);
                $('#editID').val(data.ID);
                $('#editCountryName').val(data.CountryName);
                $('#editInternationalCode').val(data.InternationalCode);
                $('#editTelecomCode').val(data.TelecomCode);
                $('#editStatus').val(data.Status);
                $('#editRemarks').val(data.Remarks);
            });   
}  
        else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
  });
     
}

function edit(ID){
     var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
          $("#editCode").addClass("highlight_error"); 
            error++;
    }  else {
         $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
    if ($('#editInternationalCode').val()==""){
            $('#ErreditInternationalCode').html("Please enter International Code");
         $("#editInternationalCode").addClass("highlight_error"); 
           error++;
    }  else {
         $("#editInternationalCode").removeClass("highlight_error"); 
            $('#ErreditInternationalCode').html(""); 
    }
    if ($('#editTelecomCode').val()==""){
            $('#ErreditTelecomCode').html("Please enter Telecom Code");
         $("#editTelecomCode").addClass("highlight_error"); 
            error++;
    }  else {
        $("#editTelecomCode").removeClass("highlight_error"); 
            $('#ErreditTelecomCode').html(""); 
    }
     /*if ($('#editCountryName').val()=="0"){
            $('#ErrediCountryName').html("Please select Country Name");
          editCountryName.style.border = "1px solid #dc3545";
          document.getElementById("ediCountryName").style["boxShadow"] = "0 0 5px #dc3545";
         
    }  else {
         document.getElementById("editCountryName").style["boxShadow"] = "";
            $('#ErreditCountryName').html(""); 
          $('#confirmationtoadd').modal("hide"); 
          $('#Success').modal("show"); 
    } */
   
    if ($('#editCountryName').val()==""){
            $('#ErreditCountryName').html("Please enter Country Name");
          $("#editCountryName").addClass("highlight_error"); 
            error++;
    }  else {
         $("#editCountryName").removeClass("highlight_error"); 
            $('#ErreditCountryName').html(""); 
    }
       if(error==0){
            var param = $('#frm_edit').serialize();
            $.post(URL+"webservice.php?action=u&method=mccol",param,function(data){
            var obj = JSON.parse(data); 
            if (obj.status=="success") {
                 $('#confirmationtoedit').modal("hide");
                 $('#Success').modal("show");  
            }   else {
                $('#ErreditCommon').html(print_inlineError(obj.message));
            }
        });
       }
}

function viewform(ID){
     $('#confirmationtoview').modal("show"); 
       $.post(URL+ "webservice.php?action=g&method=mccol&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            $.each(obj.data, function (index, data) {
                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                $('#viewCountryName').html(data.CountryName=="" ? "&nbsp;" : data.CountryName);
                $('#viewInternationalCode').html(data.InternationalCode=="" ? "&nbsp;" : data.InternationalCode);
                $('#viewTelecomCode').html(data.TelecomCode=="" ? "&nbsp;" : data.TelecomCode);
                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
               if(data.Status=="1"){
                $('#viewStatus').html("Active");    
               }
               if(data.Status=="0"){
                $('#viewStatus').html("Deactive");    
               }
            });   
}  
  })
}


//Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphanumeric without space and allowed +,-*/ 
var arr = ["TelecomCode","editTelecomCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            console.log(e.keyCode);
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [173,16,48,49,50,51,52,53,54,55,56,57,16,188,190,191,59,222,220,219,221,61,192,111,106,109,107,46,110,190,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90];
               var _allowedkeys = [61]; //when press shift
               var allowedkeys  = [32,173,9,8,46,35,36,37,38,39,40,48,49,50,51,52,53,54,55,56,57,103,104,105,100,101,102,97,98,99,96];
               if (e.shiftKey) {
                if (_allowedkeys.includes(keyCode)) {
                     notallowkeys
                } else {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                }
            } else {
                if (!(allowedkeys.includes(keyCode))) {
                    e.preventDefault();
                }  
            }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



var arr = ["InternationalCode","editInternationalCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                 var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphabets Space Dot only correct */ 
var arr = ["CountryName","editCountryName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110,190]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}        
 
$(document).ready(function(){
$(".tabs").click(function(){
$(".tabs").removeClass("active");
$(".tabs h6").removeClass("font-weight-bold");
$(".tabs h6").addClass("text-muted");
$(this).children("h6").removeClass("text-muted");
$(this).children("h6").addClass("font-weight-bold");
$(this).addClass("active");
current_fs = $(".active");
next_fs = $(this).attr('id');
next_fs = "#" + next_fs + "1";
$("fieldset").removeClass("show");
$(next_fs).addClass("show");
current_fs.animate({}, {
step: function() {
current_fs.css({
'display': 'none',
'position': 'relative'
});
next_fs.css({
'display': 'block'
});
}
});
});
});  
</script>
    